@@ -33,6 +33,7 @@ __all__ = (
     "SubscriptionStateType",
     "UnitType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -334,10 +335,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -345,3 +348,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_attacks", "list_protections"]
